#
# fishing.R,  2 Jul 23
#
# Data from:
# Transfer Learning Across Variants and Versions: The Case of Linux Kernel Size
# Hugo Martin, Mathieu Acher, Juliana Alves Pereira, Luc Lesoil, Jean-Marc Jézéquel, Djamel Eddine Khelladi

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(3)


# Data from Table 1
kv=read.csv("k_version.csv", as.is=TRUE)

plot(kv$Features, col=pal_col[1], type="b", log="y",
	yaxs="i",
	xaxt="n",
	ylim=c(200, 12000),
	xlab="Kernel version", ylab="Features")
versions=c(4.13, 4.15, "4.20", "5.0", 5.4, 5.7, 5.8)
axis(1, at=1:length(versions), labels=versions)

points(kv$New_features, col=pal_col[2], type="b")
points(kv$Deleted_features, col=pal_col[3], type="b")

legend("left", legend=c("Total features", "New features", "Deleted features"),
                        fill=pal_col, border="white", bty="n")

dev.copy(dev=png, file="kernel413-features.png")
dev.off()

# Coefficients from fitted model: lm(perf ~ ., data=kernel_413)
# summary(lo_mod)$r.squared
# 0.718
# https://zenodo.org/record/4943884
kopt=read.csv("k413coef.csv", as.is=TRUE)

mean(kopt$coef, na.rm=TRUE)
# [1] 74995.35
sd(kopt$coef, na.rm=TRUE)
# [1] 6920590

kopt=kopt[order(kopt$coef), ]

# Handle negative valued y-axis log scale
kopt$l_coef=ifelse(kopt$coef > 0, log(kopt$coef/1000), -log(abs(kopt$coef)/1000))

plot(kopt$l_coef, type="l", col="salmon",
	xaxs="i",
	yaxt="n",
	xlim=c(0, 9100),
	xlab="Option", ylab="Size change (Kb)")
bsize=c(1e2, 1e4, 1e6)
axis(2, at=c(-log(rev(bsize)), log(1), log(bsize)), labels=c(-rev(bsize), 1, bsize))

dev.copy(dev=png, file="kernel413-option-size.png")
dev.off()


